What's new in the latest versions
=================================

The new version of OMEGAlpes v0.4.0 is available!
The release is from 5th of January 2021.

.. toctree::
   :maxdepth: 2

   new_functionalities/v0.4.0


Information about the latest versions
-------------------------------------

.. toctree::
   :maxdepth: 1

   new_functionalities/v0.3.1

.. toctree::
   :maxdepth: 1

   new_functionalities/v0.3.0
